@@ -19,7 +19,9 @@ class Queue:
     def size(self):
         return len(self.items)
 
-# Mock test
+"""
+Only mock test
+
 q = Queue()
 q.enqueue(3)
 q.enqueue('json')
@@ -28,3 +30,4 @@ q.enqueue(2)
 q.isEmpty()
 
 print(q.size())
+"""
\ No newline at end of file
